Evaluation Modules
==================

Modules for evaluating generated 3D conformers.

Evaluation Classes
------------------

.. automodule:: shepherd_score.evaluations.evaluate.evals
   :members:
   :undoc-members:
   :show-inheritance:

Evaluation Pipelines
--------------------

.. automodule:: shepherd_score.evaluations.evaluate.pipelines
   :members:
   :undoc-members:
   :show-inheritance:

Docking Evaluation
------------------

Docking Classes
~~~~~~~~~~~~~~~

.. automodule:: shepherd_score.evaluations.docking.docking
   :members:
   :undoc-members:
   :show-inheritance:

Docking Pipelines
~~~~~~~~~~~~~~~~~

.. automodule:: shepherd_score.evaluations.docking.pipelines
   :members:
   :undoc-members:
   :show-inheritance:

Docking Targets
~~~~~~~~~~~~~~~

.. automodule:: shepherd_score.evaluations.docking.targets
   :members:
   :undoc-members:
   :show-inheritance:

Utility Functions
-----------------

Data Conversion
~~~~~~~~~~~~~~~

.. automodule:: shepherd_score.evaluations.utils.convert_data
   :members:
   :undoc-members:
   :show-inheritance:
